pub enum StandardIdForLabel {
AmazonOrderId,
}Expand description
StandardIdForLabel : The type of standard identifier to print on the label. The type of standard identifier to print on the label.
Variants
AmazonOrderId